# -*- coding: utf-8 -*-
from enigma import *
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.InputBox import InputBox
from Screens.ChoiceBox import ChoiceBox
from Components.ActionMap import ActionMap, NumberActionMap
from Components.ScrollLabel import ScrollLabel
from Components.GUIComponent import *
from Components.MenuList import MenuList
from Components.Input import Input
from Screens.Console import Console
from Plugins.Plugin import PluginDescriptor
import os
import gettext

freeze_version = "0.2.2"
freeze_plugindir="/usr/lib/enigma2/python/Plugins/Extensions/Freeze" 

os.environ['LANGUAGE']='en'
freeze_language='en'

if os.path.exists("/etc/enigma2/settings") == True:
   f = open("/etc/enigma2/settings")
   line = f.readline()
   while (line):
	line = f.readline().replace("\n","")
	sp = line.split("=")
	if (sp[0] == "config.osd.language"):
	   sp2 = sp[1].split("_")
           freeze_language = sp2[0]
           if os.path.exists("%s/locale/%s" % (freeze_plugindir, freeze_language)) == True:
              os.environ["LANGUAGE"] = sp[1]
           else:
              os.environ['LANGUAGE']='en'
   f.close

_=gettext.Catalog('freeze', '%s/locale' % freeze_plugindir).gettext

def main(session,**kwargs):
    session.open(FreezePlugin)

def autostart(reason,**kwargs):
    if reason == 0:
        print "[FREEZE] no autostart"

def Plugins(**kwargs):
    return [PluginDescriptor(name="Freeze Plugin", description=_("for extending and freezing your image"), where = PluginDescriptor.WHERE_PLUGINMENU, icon="freeze.png", fnc=main)]

class FreezePlugin(Screen):
    skin = """
        <screen position="150,200" size="420,300" title="Freeze Plugin Menu" >
            <widget name="menu" position="10,10" size="410,290" scrollbarMode="showOnDemand" />
        </screen>"""
        
    def __init__(self, session, args = 0):
        self.skin = FreezePlugin.skin
        self.session = session
        Screen.__init__(self, session)
        self.menu = args
        freezelist = []
        freezelist.append((_("check freeze and unionfs"), "checkfreeze"))
        freezelist.append((_("show freespace of root"), "freespace"))
        if os.path.exists("/boot/mnt/freeze/freeze") is True:
           freezelist.append((_("list freeze delta content"), "listfreeze"))
        freezelist.append((_("automatically choose freeze delta device"), "deltafreeze"))
        if os.path.exists("/.freeze") is False:
           freezelist.append((_("enable freeze of Flash image"), "freeze"))
        else:
           if os.path.exists("/boot/mnt/flash/squashfs") is False:
              freezelist.append((_("disable freeze and unionfs"), "disablefreeze"))
           else:
              freezelist.append((_("disable freeze"), "disablefreeze"))
        if os.path.exists("/boot/mnt/flash/squashfs") is False:
           freezelist.append((_("enable unfrozen unionfs without delta"), "unionfs"))
        freezelist.append((_("extend unionfs"), "unionfsextend"))
        freezelist.append((_("erase freeze delta"), "erasefreeze"))
        freezelist.append((_("syncronize image with freeze delta"), "freezesync"))        
        freezelist.append((_("Freeze readme.txt"), "readmefreeze"))        
        freezelist.append((_("about Freeze Version %s") % freeze_version, "aboutfreeze"))        
        self["menu"] = MenuList(freezelist)
        self["actions"] = ActionMap(["WizardActions", "DirectionActions"],{"ok": self.go,"back": self.close,}, -1)
        
    def go(self):
        returnValue = self["menu"].l.getCurrentSelection()[1]
        if returnValue is not None:
           if returnValue is "freeze":
              Freeze(self.session)
           elif returnValue is "freezesync":
              FreezeSync(self.session)
           elif returnValue is "unionfs":
              title = _("enable unfrozen unionfs without delta")
              cmd = "freeze unionfs" 
              self.session.open(Console,_(title),[cmd])
           elif returnValue is "deltafreeze":
              title = _("automatically chose freeze delta device")
              cmd = "freeze delta" 
              self.session.open(Console,_(title),[cmd])
           elif returnValue is "listfreeze":
              title = _("list freeze delta content")
              cmd = "freeze list" 
              self.session.open(Console,_(title),[cmd])
           elif returnValue is "erasefreeze":
              title = _("erase freeze delta")
              cmd = "freeze erase" 
              self.session.open(Console,_(title),[cmd])
           elif returnValue is "checkfreeze":
              title = _("checking freeze and unionfs mounts")
              cmd = "freeze check" 
              self.session.open(Console,_(title),[cmd])
           elif returnValue is "disablefreeze":
              title = _("disabling freeze")
              cmd = "freeze disable" 
              self.session.open(Console,_(title),[cmd])
           elif returnValue is "freespace":
              title = _("freespace in image")
              cmd = "freeze free" 
              self.session.open(Console,_(title),[cmd])
           elif returnValue is "readmefreeze":
              self.session.open(Console,_("Freeze readme.txt"),["cat %s/locale/%s/LC_MESSAGES/readme.txt" % (freeze_plugindir,freeze_language)])
           elif returnValue is "unionfsextend":
              if os.path.exists("/boot/mnt/flash/squashfs") is True:
                 title=_("not yet implemented !!!\nuse unionctl / --add /directory")
              else:
                 title=_("not yet implemented !!!\nuse unionctl /boot/mnt/root --add /directory")
              self.session.open(MessageBox, title,  MessageBox.TYPE_WARNING)
           elif returnValue is "aboutfreeze":
              title=_("Freeze Plugin %s by gutemine") % (freeze_version)
              self.session.open(MessageBox, title,  MessageBox.TYPE_INFO)

class Freeze(Screen):
    def __init__(self, session):
        self.session = session
        self.session.openWithCallback(self.askForFreeze,MessageBox,(_("are you sure to freeze image ?")), MessageBox.TYPE_YESNO)
        
    def askForFreeze(self,answer):
        if answer is None:
            self.skipFreeze(_("answer is None"))
        if answer is False:
            self.skipFreeze(_("you were not confirming"))
        else:
            title = _("enabling freeze to delta")
            cmd = "freeze enable"
            self.session.open(Console,_(title),[cmd])
            
    def skipFreeze(self,reason):
        self.session.open(MessageBox,_("Freeze was canceled, because %s") % reason, MessageBox.TYPE_ERROR)

class FreezeSync(Screen):
    def __init__(self, session):
        self.session = session
        self.session.openWithCallback(self.askForSyncFreeze,MessageBox,(_("are you sure to freeze sync image from freeze delta ?")), MessageBox.TYPE_YESNO)
        
    def askForSyncFreeze(self,answer):
        if answer is None:
            self.skipSyncFreeze(_("answer is None"))
        if answer is False:
            self.skipSyncFreeze(_("you were not confirming"))
        else:
            title = _("enabling freeze synchronize from delta")
            cmd = "freeze synchronize" 
            self.session.open(Console,_(title),[cmd])
            
    def skipSyncFreeze(self,reason):
        self.session.open(MessageBox,_("Freeze delta synchronisation was canceled, because %s") % reason, MessageBox.TYPE_ERROR)

